/* --COPYRIGHT--,BSD
 * Copyright (c) 2012, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/
//******************************************************************************
//!  AES256 Encryption and Decryption Example
//!
//!  Description: This demo shows how to use the AES Encryption and Decryption
//!
//!               MSP430FR5969
//!             -----------------

//!
//! This example uses the following peripherals and I/O signals.  You must
//! review these and change as needed for your own board:
//! - WDT peripheral
//! - AES256
//!
//! This example uses the following interrupt handlers.  To use this example
//! in your own application you must add these interrupt handlers to your
//! vector table.
//! - None.
//******************************************************************************
//#include "inc/hw_memmap.h"
#include "msp430fr5969.h"
#include "driverlib/5xx_6xx/wdt.h"
#include "driverlib/5xx_6xx/aes256.h"

unsigned char Data[16] = 		{	0x30, 0x30, 0x30, 0x30,
	 								0x30, 0x30, 0x30, 0x30,
	 								0x30, 0x30, 0x30, 0x30,
	 								0x30, 0x30, 0x30, 0x30	};

unsigned char CipherKey[32] = 	{	0xAA, 0xBB, 0x02, 0x03,
									0x04, 0x05, 0x06, 0x07,
									0x08, 0x09, 0x0A, 0x0B,
									0x0C, 0x0D, 0x0E, 0x0F,
									0x30, 0x31, 0x32, 0x33,
									0x34, 0x35, 0x36, 0x37,
									0x30, 0x31, 0x32, 0x33,
									0x34, 0x35, 0x36, 0x37	};
unsigned char DataAESencrypted[16];		// Encrypted data
unsigned char DataAESdecrypted[16];		// Decrypted data
int i = 0;

void main(void){
	// stop watchdog
	WDT_hold(__MSP430_BASEADDRESS_WDT_A__);

	// Load a cipher key to module
	AES256_setCipherKey(__MSP430_BASEADDRESS_AES256__, CipherKey, Key_256BIT);

	// Encrypt data with preloaded cipher key
	AES256_encryptData(__MSP430_BASEADDRESS_AES256__, Data, DataAESencrypted);
	
	// Decrypt data with keys that were generated during encryption - takes 214 MCLK
	// This function will generate all round keys needed for decryption first and then
	// the encryption process starts
	AES256_decryptDataUsingEncryptionKey(__MSP430_BASEADDRESS_AES256__, DataAESencrypted, DataAESdecrypted);

	// Array DataunAES should now contain the same data as array Data

    while(1){};
}

