/* --COPYRIGHT--,BSD
 * Copyright (c) 2012, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/

//#include "inc/hw_memmap.h"
#include "msp430fr5969.h"
#include "driverlib/5xx_6xx/cs_a.h"
#include "driverlib/5xx_6xx/wdt.h"
#include "driverlib/5xx_6xx/frgpio.h"

//******************************************************************************
//   MSP430FR59xx Demo - Configure MCLK for 24MHz operation
//
//   Description: Configure SMCLK = MCLK = 24MHz
//   IMPORTANT NOTE: While the FRxxx is capable of operation w/ MCLK = 24MHz
//   the throughput of the device is dependent on accesses to FRAM.
//   The maximum speed for accessing FRAM is limited to 8MHz*.
//   Wait states are inserted automatically when the FRAM is accessed at
//   speeds higher than 8MHz to prevent timing violations.
//   Refer to the FRCTL chapter of the User's Guide.
//   * Refer device D/s for typical numbers
//
//           MSP430FR5969
//         ---------------
//     /|\|               |
//      | |               |
//      --|RST            |
//        |               |
//        |               |
//        |          P3.4 |---> SMCLK = MCLK = 24MHz
//
//******************************************************************************

unsigned long clockValue;
	
void main(void)
{

	
  //Stop WDT
  WDT_hold(__MSP430_BASEADDRESS_WDT_A__);
  CSA_setDCOFreq(__MSP430_BASEADDRESS_CS_A__,CSA_DCORSEL_1,CSA_DCOFSEL_6);

  CSA_clockSignalInit(__MSP430_BASEADDRESS_CS_A__,CSA_SMCLK,CSA_DCOCLK_SELECT,CSA_CLOCK_DIVIDER_1);
  CSA_clockSignalInit(__MSP430_BASEADDRESS_CS_A__,CSA_MCLK,CSA_DCOCLK_SELECT,CSA_CLOCK_DIVIDER_1);


  //Set P2.0 as Output Low (for setup as ACLK).
  /*
   * Base Address for Port 2
   * Select Port 2
   * Set Pin 0 to output Low.
   */
  FRGPIO_setOutputLowOnPin(__MSP430_BASEADDRESS_PORT3_R__,
			FRGPIO_PORT_P3,
			FRGPIO_PIN4
	);

  //Set P2.0 as Ternary Module Function Output.
  /*
   * Base Address for Port 2
   * Select Port 2
   * Set Pin 0 to output Ternary Module Function, (ACLK).
   */
  FRGPIO_setAsPeripheralModuleFunctionOutputPin(__MSP430_BASEADDRESS_PORT3_R__,
			FRGPIO_PORT_P3,
			FRGPIO_PIN4,
			FRGPIO_TERNARY_MODULE_FUNCTION
	);

  while(1);

}


