/* --COPYRIGHT--,BSD
 * Copyright (c) 2012, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/
#include "inc/hw_memmap.h"
#include "driverlib/5xx_6xx/fram.h"
#include "driverlib/5xx_6xx/wdt.h"
#include "driverlib/5xx_6xx/cs.h"
#include "driverlib/5xx_6xx/frgpio.h"
#include "driverlib/5xx_6xx/ref.h"

//******************************************************************************
//!   MSP430FR57xx Demo - Long word writes to FRAM
//!
//!   Description: Use long word write to write to 512 byte blocks of FRAM.
//!   Toggle LEDs after every 100 writes.
//!   NOTE: Running this example for extended periods will impact the FRAM
//!   endurance.
//!   ACLK = VLO, MCLK = SMCLK = 4MHz
//!
//!           MSP430FR573x
//!         ---------------
//!     /|\|               |
//!      | |               |
//!      --|RST            |
//!        |               |
//!        |               |
//!        |           P1.0|---> LED
//!		   |           P3.5|-->LED
//!
//!   Built with IAR Embedded Workbench Version: 5.40 & Code Composer Studio V5.1
//******************************************************************************

#define FRAM_TEST_START 0xCA00

void main(void)
{
  unsigned char count = 0;
  unsigned long data=0;
  
  WDT_hold(__MSP430_BASEADDRESS_WDT_A__);                 // Stop WDT


  // Configure MCLK for 4MHz operation
  //Set DCO frequency to 8MHz
  CS_setDCOFreq(__MSP430_BASEADDRESS_CS__,CS_DCORSEL_0,CS_DCOFSEL_3);
  //Set ACLK = VLO with frequency divider of 1
  CS_clockSignalInit(__MSP430_BASEADDRESS_CS__,CS_ACLK,CS_VLOCLK_SELECT,CS_CLOCK_DIVIDER_1);
  //Set SMCLK = DCO with frequency divider of 2
  CS_clockSignalInit(__MSP430_BASEADDRESS_CS__,CS_ACLK,CS_DCOCLK_SELECT,CS_CLOCK_DIVIDER_2);
  //Set MCLK = DCO with frequency divider of 2
  CS_clockSignalInit(__MSP430_BASEADDRESS_CS__,CS_ACLK,CS_DCOCLK_SELECT,CS_CLOCK_DIVIDER_2);

  // Turn off Temperature sensor and Reference Voltage.
  REF_disableTempSensor(__MSP430_BASEADDRESS_REF__);
  REF_disableReferenceVoltage(__MSP430_BASEADDRESS_REF__);

  //Set P1.0 as an output pin.
  /*
   * Base Address for Port 1
   * Select Port 1
   * Set Pin 0 as output
   */
	FRGPIO_setAsOutputPin(__MSP430_BASEADDRESS_PORT1_R__,
			FRGPIO_PORT_P1,
			FRGPIO_PIN0
	);
	//Set P3.5 as an output pin.
    /*
     * Base Address for Port 3
     * Select Port 3
     * Set Pin 5 as output
     */
	FRGPIO_setAsOutputPin(__MSP430_BASEADDRESS_PORT3_R__,
			FRGPIO_PORT_P3,
			FRGPIO_PIN5);

  // Initialize dummy data
  data = 0x11111111;

  while(1)
  {
          data += 0x00010001;

          FRAM_memoryFill32(__MSP430_BASEADDRESS_FRAM_FR5XX__,data,(unsigned long *)FRAM_TEST_START,128);
          count++;
          if (count > 100)
          {
			//Toggle P1.0 output pin.
			/*
			* Base Address for Port 1
			* Select Port 1
			* Set Pin 0 as output
			*/
			FRGPIO_toggleOutputOnPin(__MSP430_BASEADDRESS_PORT1_R__,
				FRGPIO_PORT_P1,
				FRGPIO_PIN0
				);
			//Toggle P3.5 output pin.
			/*
			* Base Address for Port 3
			* Select Port 3
			* Set Pin 5 as output
			*/
			FRGPIO_toggleOutputOnPin(__MSP430_BASEADDRESS_PORT3_R__,
				FRGPIO_PORT_P3,
				FRGPIO_PIN5
			);


            count = 0;                            //Reset counter
            data = 0x11111111;
          }
  }
}
