/* --COPYRIGHT--,BSD
 * Copyright (c) 2012, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/
//******************************************************************************
//   Write a Word to Port A (Port1+Port2)
//
//   Writes a Word(FFFFh) to Port A and stays in LPM4
//   ACLK = 32.768kHz, MCLK = SMCLK = default DCO
//
//                MSP430FR5969
//             -----------------
//         /|\|                 |
//          | |                 |
//          --|RST          PA.x|-->HI
//            |                 |
//            |                 |
//
//
//   This example uses the following peripherals and I/O signals.  You must
//   review these and change as needed for your own board:
//   - GPIO Port peripheral
//   
//   This example uses the following interrupt handlers.  To use this example
//   in your own application you must add these interrupt handlers to your
//   vector table.
//   - None.
//
//   Nick Angelou
//   Texas Instruments Inc.
//   February 2012
//   Built with IAR Embedded Workbench Version: 5.40 & Code Composer Studio V5.1
//******************************************************************************

#include "inc/hw_memmap.h"
#include "driverlib/5xx_6xx/frgpio.h"
#include "driverlib/5xx_6xx/wdt.h"

void main (void)
{
    //Stop WDT
    WDT_hold(__MSP430_BASEADDRESS_WDT_A__);

    //PA.x output
    FRGPIO_setAsOutputPin(__MSP430_BASEADDRESS_PORT1_R__,
        FRGPIO_PORT_PA,
        FRGPIO_PIN0 + FRGPIO_PIN1 + FRGPIO_PIN2 + FRGPIO_PIN3 +
        FRGPIO_PIN4 + FRGPIO_PIN5 + FRGPIO_PIN6 + FRGPIO_PIN7 +
        FRGPIO_PIN8 + FRGPIO_PIN9 + FRGPIO_PIN10 + FRGPIO_PIN11 +
        FRGPIO_PIN12 + FRGPIO_PIN13 + FRGPIO_PIN14 + FRGPIO_PIN15
        );


    //Set all PA pins HI
    FRGPIO_setOutputHighOnPin(
        __MSP430_BASEADDRESS_PORT1_R__,
        FRGPIO_PORT_PA,
        FRGPIO_PIN0 + FRGPIO_PIN1 + FRGPIO_PIN2 + FRGPIO_PIN3 +
        FRGPIO_PIN4 + FRGPIO_PIN5 + FRGPIO_PIN6 + FRGPIO_PIN7 +
        FRGPIO_PIN8 + FRGPIO_PIN9 + FRGPIO_PIN10 + FRGPIO_PIN11 +
        FRGPIO_PIN12 + FRGPIO_PIN13 + FRGPIO_PIN14 + FRGPIO_PIN15
        );

    //Enter LPM4 w/interrupts enabled
    __bis_SR_register(LPM4_bits + GIE);

    //For debugger
    __no_operation();
}

