/* --COPYRIGHT--,BSD
 * Copyright (c) 2012, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/
//******************************************************************************
//   Software Port Interrupt Service on P1.4 from LPM4 with
//                     Internal Pull-up Resistance Enabled
//  
//   A hi "TO" low transition on P1.4 will trigger P1_ISR which,
//   toggles P1.0. P1.4 is internally enabled to pull-up. Normal mode is
//   LPM4 ~ 0.1uA. LPM4 current can be measured with the LED removed, all
//   unused Px.x configured as output or inputs pulled high or low.
//   ACLK = n/a, MCLK = SMCLK = default DCO
//  
//                MSP430FR5969
//             -----------------
//         /|\|              XIN|-
//          | |                 |
//          --|RST          XOUT|-
//      /|\   |                 |
//       --o--|P1.4         P1.0|-->LED
//      \|/
//  
//   This example uses the following peripherals and I/O signals.  You must
//   review these and change as needed for your own board:
//   - GPIO Port peripheral
//   
//   This example uses the following interrupt handlers.  To use this example
//   in your own application you must add these interrupt handlers to your
//   vector table.
//   - PORT1_VECTOR
//  
//   Nick Angelou
//   Texas Instruments Inc.
//   February 2012
//   Built with IAR Embedded Workbench Version: 5.40 & Code Composer Studio V5.1
//******************************************************************************
#include "inc/hw_memmap.h"
#include "driverlib/5xx_6xx/frgpio.h"
#include "driverlib/5xx_6xx/wdt.h"

void main (void)
{
    //Stop watchdog timer
    WDT_hold(__MSP430_BASEADDRESS_WDT_A__);

    //Set P1.0 to output direction
    FRGPIO_setAsOutputPin(__MSP430_BASEADDRESS_PORT1_R__,
        FRGPIO_PORT_P1,
        FRGPIO_PIN0
        );



    //Enable P1.4 internal resistance as pull-Up resistance
    FRGPIO_setAsInputPinWithPullUpresistor(
        __MSP430_BASEADDRESS_PORT1_R__,
        FRGPIO_PORT_P1,
        FRGPIO_PIN4
        );

    //P1.4 interrupt enabled
    FRGPIO_enableInterrupt(
        __MSP430_BASEADDRESS_PORT1_R__,
        FRGPIO_PORT_P1,
        FRGPIO_PIN4
        );

    //P1.4 Hi/Lo edge
    FRGPIO_interruptEdgeSelect(
        __MSP430_BASEADDRESS_PORT1_R__,
        FRGPIO_PORT_P1,
        FRGPIO_PIN4,
        FRGPIO_HIGH_TO_LOW_TRANSITION
        );


    //P1.4 IFG cleared
    FRGPIO_clearInterruptFlag(
        __MSP430_BASEADDRESS_PORT1_R__,
        FRGPIO_PORT_P1,
        FRGPIO_PIN4
        );

    //Enter LPM4 w/interrupt
    __bis_SR_register(LPM4_bits + GIE);

    //For debugger
    __no_operation();
}

//******************************************************************************
//
//This is the PORT1_VECTOR interrupt vector service routine
//
//******************************************************************************
#pragma vector=PORT1_VECTOR
__interrupt void Port_1 (void)
{
    //P1.0 = toggle
    FRGPIO_toggleOutputOnPin(
        __MSP430_BASEADDRESS_PORT1_R__,
        FRGPIO_PORT_P1,
        FRGPIO_PIN0
        );


    //P1.4 IFG cleared
    FRGPIO_clearInterruptFlag(
        __MSP430_BASEADDRESS_PORT1_R__,
        FRGPIO_PORT_P1,
        FRGPIO_PIN4
        );
}

